CoroutineWithParam<T> typedef
CoroutineWithParam<T> =
Iterable Function(T param)
A Coroutine that takes one argument, so a caller can start the same body for several entities without a closure per start.
Implementation
typedef CoroutineWithParam<T> = Iterable Function(T param);