GameSystemLifecycleListener mixin
- Superclass constraints
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- listensToEvents → bool
-
Whether this listener should receive events right now.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableAfterUncaught(
) → void -
Stops this listener receiving events, after it threw out of one.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMounted(
) → void -
onUnmounted(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited